@@ -1,6 +1,7 @@
 package App::Office::Contacts::Controller::Exporter::Organization;
 
-use common::sense;
+use strict;
+use warnings;
 
 use App::Office::Contacts::Util::Validator;
 
@@ -19,7 +20,7 @@ use Sub::Exporter -setup =>
 	/],
 };
 
-our $VERSION = '1.14';
+our $VERSION = '1.16';
 
 # -----------------------------------------------
 
@@ -29,8 +30,6 @@ sub add
 
 	$self -> log(debug => 'Entered add');
 
-	return if ($self -> validate_post == 0);
-
 	my($result) = App::Office::Contacts::Util::Validator -> new
 	(
 		config => $self -> param('config'),
@@ -92,8 +91,6 @@ sub display
 
 	$self -> log(debug => 'Entered display');
 
-	return if ($self -> validate_post == 0);
-
 	my($id)           = $self -> query -> param('target_id');
 	my($organization) = $self -> param('db') -> organization -> get_organization($self -> param('user_id'), $id);
 	my($result)       = "No organization has the requested id. (Hint: Run another search)";
@@ -135,8 +132,6 @@ sub update
 
 	$self -> log(debug => 'Entered update');
 
-	return if ($self -> validate_post == 0);
-
 	my($id)           = $self -> query -> param('target_id'); # TODO
 	my($action)       = $self -> query -> param('submit_organization_delete') || 'Update';
 	my($name)         = $self -> query -> param('name') || '';
